<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:map="urn:brgm:mapping" xmlns:gmd="http://www.isotc211.org/2005/gmd" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:gml="http://www.opengis.net/gml" xmlns:gts="http://www.isotc211.org/2005/gts" xmlns:gmx="http://www.isotc211.org/2005/gmx" xmlns:gfc="http://www.isotc211.org/2005/gfc" xmlns:gco="http://www.isotc211.org/2005/gco" xmlns:fra="http://www.cnig.gouv.fr/2005/fra">
	<xsl:variable name="fileMapping" select="document('./fileMappingEsri.xpa')"/>
	<!--Initial template for MD_Metadata -->
	<xsl:template match="/metadata">
		<gmd:MD_Metadata xmlns:gmd="http://www.isotc211.org/2005/gmd" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:gml="http://www.opengis.net/gml" xmlns:gts="http://www.isotc211.org/2005/gts" xmlns:gmx="http://www.isotc211.org/2005/gmx" xmlns:gfc="http://www.isotc211.org/2005/gfc" xmlns:gco="http://www.isotc211.org/2005/gco" xmlns:fra="http://www.cnig.gouv.fr/2005/fra" xsi:schemaLocation="http://www.isotc211.org/2005/gmd ../schemas/iso19139fra/gmd/gmd.xsd">
			<!-- identifier. Two possibilities-->
			<gmd:fileIdentifier>
				<gco:CharacterString>
					<xsl:choose>
						<xsl:when test="metadata/mdFileID">
							<xsl:value-of select="metadata/mdFileID"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="idinfo/citation/citeinfo/title"/>
						</xsl:otherwise>
					</xsl:choose>
				</gco:CharacterString>
			</gmd:fileIdentifier>
			<!-- language metadata -->
			<gmd:language>
				<gco:CharacterString>fre</gco:CharacterString>
			</gmd:language>
			<!-- CharacterSet of MD-->
			<gmd:characterSet>
				<xsl:call-template name="charEsri">
					<xsl:with-param name="val">
						<xsl:value-of select="mdChar/CharSetCd/@value"/>
					</xsl:with-param>
				</xsl:call-template>
			</gmd:characterSet>
			<!-- hierarchyLevel MD-->
			<gmd:hierarchyLevel>
				<xsl:call-template name="hierEsri">
					<xsl:with-param name="val">
						<xsl:value-of select="mdHrLv/ScopeCd/@value"/>
					</xsl:with-param>
				</xsl:call-template>
			</gmd:hierarchyLevel>
			<!-- hierarchyLevelName = hierarchyLevel -->
			<gmd:hierarchyLevelName>
				<xsl:call-template name="hierNameEsri">
					<xsl:with-param name="val">
						<xsl:value-of select="mdHrLv/ScopeCd/@value"/>
					</xsl:with-param>
				</xsl:call-template>
			</gmd:hierarchyLevelName>
			<!-- contact of MD -->
			<gmd:contact>
				<xsl:call-template name="cntEsri">
					<xsl:with-param name="val" select="mdContact"/>
					<xsl:with-param name="roleint" select="mdContact"/>
				</xsl:call-template>
			</gmd:contact>
			<!-- date of MD -->
			<gmd:dateStamp>
				<gco:Date>
					<xsl:call-template name="dateEsri">
						<xsl:with-param name="ladate" select="metainfo/metd"/>
					</xsl:call-template>
				</gco:Date>
			</gmd:dateStamp>
			<!-- standard name -->
			<gmd:metadataStandardName>
				<gco:CharacterString>ISO 19115 FRA 1.0</gco:CharacterString> 
			</gmd:metadataStandardName>
			<!-- standard version-->
			<gmd:metadataStandardVersion>
				<gco:CharacterString>
					<xsl:value-of select="metainfo/metstdv"/>
				</gco:CharacterString>
			</gmd:metadataStandardVersion>
			<!-- Spatial representation -->
			<xsl:for-each select="spdoinfo/ptvctinf/esriterm">
				<xsl:call-template name="spRepInfo">
					<xsl:with-param name="val" select="."/>
				</xsl:call-template>
			</xsl:for-each>
			<!-- CRS-->
			<xsl:for-each select="spref">
				<xsl:call-template name="spref">
					<xsl:with-param name="val" select="."/>
				</xsl:call-template>
			</xsl:for-each>
			<!-- Identification -->
			<xsl:for-each select="idinfo">
				<xsl:call-template name="idinfo">
					<xsl:with-param name="val" select="."/>
				</xsl:call-template>
			</xsl:for-each>
			<!-- Distribution -->
			<xsl:for-each select="distinfo">
				<xsl:call-template name="distinfo">
					<xsl:with-param name="val" select="."/>
				</xsl:call-template>
			</xsl:for-each>
			<!-- quality Information -->
			<xsl:if test="dqInfo">
				<xsl:call-template name="dataqual">
					<xsl:with-param name="val" select="dqInfo"/>
				</xsl:call-template>
			</xsl:if>
			<!-- constraints access MD -->
			<xsl:if test="metainfo/metac">
				<gmd:metadataConstraints>
					<gmd:MD_LegalConstraints>
						<gmd:accessConstraints>
							<gmd:MD_RestrictionCode codeListValue="otherRestrictions" codeList="MD_RestrictionCode"/>
						</gmd:accessConstraints>
						<gmd:otherConstraints>
							<gco:CharacterString>
								<xsl:value-of select="metainfo/metac"/>
							</gco:CharacterString>
						</gmd:otherConstraints>
					</gmd:MD_LegalConstraints>
				</gmd:metadataConstraints>
			</xsl:if>
			<!-- constraints use MD -->
			<xsl:if test="metainfo/metuc">
				<gmd:metadataConstraints>
					<gmd:MD_LegalConstraints>
						<gmd:accessConstraints>
							<gmd:MD_RestrictionCode codeListValue="otherRestrictions" codeList="MD_RestrictionCode"/>
						</gmd:accessConstraints>
						<gmd:otherConstraints>
							<gco:CharacterString>
								<xsl:value-of select="metainfo/metuc"/>
							</gco:CharacterString>
						</gmd:otherConstraints>
					</gmd:MD_LegalConstraints>
				</gmd:metadataConstraints>
			</xsl:if>
			<!-- security constraints MD -->
			<xsl:if test="metainfo/metsi">
				<gmd:metadataConstraints>
					<gmd:MD_SecurityConstraints>
						<gmd:useLimitation>
							<gco:CharacterString/>
						</gmd:useLimitation>
						<gmd:classification>
							<xsl:call-template name="securityEsri">
								<xsl:with-param name="val">
									<xsl:value-of select="metainfo/metsi/metsc"/>
								</xsl:with-param>
							</xsl:call-template>
						</gmd:classification>
						<gmd:classificationSystem>
							<gco:CharacterString>
								<xsl:value-of select="metainfo/metsi/metscs"/>
							</gco:CharacterString>
						</gmd:classificationSystem>
						<gmd:handlingDescription>
							<gco:CharacterString>
								<xsl:value-of select="metainfo/metsi/metshd"/>
							</gco:CharacterString>
						</gmd:handlingDescription>
					</gmd:MD_SecurityConstraints>
				</gmd:metadataConstraints>
			</xsl:if>
		</gmd:MD_Metadata>

	</xsl:template>
	<!--Template for mapping characterSetCode -->
	<xsl:template name="charEsri">
		<xsl:param name="val"/>
		<gmd:MD_CharacterSetCode>
			<xsl:attribute name="codeList">MD_CharacterSetCode</xsl:attribute>
			<xsl:attribute name="codeListValue"><xsl:value-of select="$fileMapping/map:Mapping/map:MD_CharacterSetCode/map:code[@esri=$val]/@value"/></xsl:attribute>
		</gmd:MD_CharacterSetCode>
	</xsl:template>
	<xsl:template name="hierEsri">
		<xsl:param name="val"/>
		<gmd:MD_ScopeCode>
			<xsl:attribute name="codeList">MD_ScopeCode</xsl:attribute>
			<xsl:attribute name="codeListValue"><xsl:value-of select="$fileMapping/map:Mapping/map:MD_ScopeCode/map:code[@esri=$val]/@value"/></xsl:attribute>
		</gmd:MD_ScopeCode>
	</xsl:template>
	<xsl:template name="hierNameEsri">
		<xsl:param name="val"/>
		<gco:CharacterString>
			<xsl:value-of select="$fileMapping/map:Mapping/map:MD_ScopeCode/map:code[@esri=$val]/@value"/>
		</gco:CharacterString>
	</xsl:template>
	<!--Responsible party -->
	<xsl:template name="cntEsri">
		<xsl:param name="val"/>
		<!--xsl:param name="roleInt"/-->
		<gmd:CI_ResponsibleParty>
			<gmd:individualName>
				<gco:CharacterString>
					<xsl:value-of select="$val/rpIndName"/>
				</gco:CharacterString>
			</gmd:individualName>
			<gmd:organisationName>
				<gco:CharacterString>
					<xsl:value-of select="$val/rpOrgName"/>
				</gco:CharacterString>
			</gmd:organisationName>
			<gmd:positionName>
				<gco:CharacterString>
					<xsl:value-of select="$val/rpPosName"/>
				</gco:CharacterString>
			</gmd:positionName>
			<gmd:contactInfo>
				<gmd:CI_Contact>
					<gmd:phone>
						<gmd:CI_Telephone>
							<gmd:voice>
								<gco:CharacterString>
									<xsl:value-of select="$val/rpCntInfo/cntPhone/voiceNum"/>
								</gco:CharacterString>
							</gmd:voice>
							<gmd:facsimile>
								<gco:CharacterString>
									<xsl:value-of select="$val/rpCntInfo/cntPhone/faxNum"/>
								</gco:CharacterString>
							</gmd:facsimile>
						</gmd:CI_Telephone>
					</gmd:phone>
					<gmd:address>
						<gmd:CI_Address>
							<gmd:deliveryPoint>
								<gco:CharacterString>
									<xsl:value-of select="$val/rpCntInfo/cntAddress/delPoint"/>
								</gco:CharacterString>
							</gmd:deliveryPoint>
							<gmd:city>
								<gco:CharacterString>
									<xsl:value-of select="$val/rpCntInfo/cntAddress/city"/>
								</gco:CharacterString>
							</gmd:city>
							<gmd:administrativeArea>
								<gco:CharacterString>
									<xsl:value-of select="$val/cntaddr/state"/>
								</gco:CharacterString>
							</gmd:administrativeArea>
							<gmd:postalCode>
								<gco:CharacterString>
									<xsl:value-of select="$val/rpCntInfo/cntAddress/postCode"/>
								</gco:CharacterString>
							</gmd:postalCode>
							<gmd:country>
								<gco:CharacterString>
									<xsl:value-of select="$val/cntaddr/country"/>
								</gco:CharacterString>
							</gmd:country>
							<gmd:electronicMailAddress>
								<gco:CharacterString>
									<xsl:value-of select="$val/rpCntInfo/cntAddress/eMailAdd"/>
								</gco:CharacterString>
							</gmd:electronicMailAddress>
						</gmd:CI_Address>
					</gmd:address>
				</gmd:CI_Contact>
			</gmd:contactInfo>
			<gmd:role>
				<xsl:choose>
					<xsl:when test="role/RoleCd/@value='001'">
						<gmd:CI_RoleCode codeListValue="resourceProvider" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:when test="role/RoleCd/@value='002'">
						<gmd:CI_RoleCode codeListValue="custodian" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:when test="role/RoleCd/@value='003'">
						<gmd:CI_RoleCode codeListValue="owner" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:when test="role/RoleCd/@value='004'">
						<gmd:CI_RoleCode codeListValue="user" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:when test="role/RoleCd/@value='005'">
						<gmd:CI_RoleCode codeListValue="distributor" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:when test="role/RoleCd/@value='006'">
						<gmd:CI_RoleCode codeListValue="originator" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:when test="role/RoleCd/@value='007'">
						<gmd:CI_RoleCode codeListValue="pointOfContact" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:when test="role/RoleCd/@value='008'">
						<gmd:CI_RoleCode codeListValue="principalInvestigator" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:when test="role/RoleCd/@value='009'">
						<gmd:CI_RoleCode codeListValue="processor" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:when test="role/RoleCd/@value='010'">
						<gmd:CI_RoleCode codeListValue="publisher" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:when test="role/RoleCd/@value='011'">
						<gmd:CI_RoleCode codeListValue="author" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:when test="mdContact/role/RoleCd/@value='001'">
						<gmd:CI_RoleCode codeListValue="resourceProvider" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:when test="mdContact/role/RoleCd/@value='002'">
						<gmd:CI_RoleCode codeListValue="custodian" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:when test="mdContact/role/RoleCd/@value='003'">
						<gmd:CI_RoleCode codeListValue="owner" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:when test="mdContact/role/RoleCd/@value='004'">
						<gmd:CI_RoleCode codeListValue="user" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:when test="mdContact/role/RoleCd/@value='005'">
						<gmd:CI_RoleCode codeListValue="distributor" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:when test="mdContact/role/RoleCd/@value='006'">
						<gmd:CI_RoleCode codeListValue="originator" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:when test="mdContact/role/RoleCd/@value='007'">
						<gmd:CI_RoleCode codeListValue="pointOfContact" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:when test="mdContact/role/RoleCd/@value='008'">
						<gmd:CI_RoleCode codeListValue="principalInvestigator" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:when test="mdContact/role/RoleCd/@value='009'">
						<gmd:CI_RoleCode codeListValue="processor" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:when test="mdContact/role/RoleCd/@value='010'">
						<gmd:CI_RoleCode codeListValue="publisher" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:when test="mdContact/role/RoleCd/@value='011'">
						<gmd:CI_RoleCode codeListValue="author" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:when test="role/RoleCd/@value='007'">
						<gmd:CI_RoleCode codeListValue="pointOfContact" codeList="CI_RoleCode"/>
					</xsl:when>
					<xsl:otherwise>
						<gmd:CI_RoleCode codeListValue="unknown" codeList="CI_RoleCode"/>
					</xsl:otherwise>
				</xsl:choose>
			</gmd:role>
		</gmd:CI_ResponsibleParty>
	</xsl:template>
	<!--Responsible party -->
	<xsl:template name="distEsri">
		<xsl:param name="val"/>
		<xsl:param name="roleInt"/>
		<gmd:CI_ResponsibleParty>
			<gmd:individualName>
				<gco:CharacterString>
					<xsl:value-of select="$val/rpIndName"/>
				</gco:CharacterString>
			</gmd:individualName>
			<gmd:organisationName>
				<gco:CharacterString>
					<xsl:value-of select="$val//rpOrgName"/>
				</gco:CharacterString>
			</gmd:organisationName>
			<gmd:positionName>
				<gco:CharacterString>
					<xsl:value-of select="$val//rpPosName"/>
				</gco:CharacterString>
			</gmd:positionName>
			<gmd:contactInfo>
				<gmd:CI_Contact>
					<gmd:phone>
						<gmd:CI_Telephone>
							<gmd:voice>
								<gco:CharacterString>
									<xsl:value-of select="$val//rpCntInfo/cntPhone/voiceNum"/>
								</gco:CharacterString>
							</gmd:voice>
							<gmd:facsimile>
								<gco:CharacterString>
									<xsl:value-of select="$val//rpCntInfo/cntPhone/faxNum"/>
								</gco:CharacterString>
							</gmd:facsimile>
						</gmd:CI_Telephone>
					</gmd:phone>
					<gmd:address>
						<gmd:CI_Address>
							<gmd:deliveryPoint>
								<gco:CharacterString>
									<xsl:value-of select="$val/rpCntInfo/cntAddress/delPoint"/>
								</gco:CharacterString>
							</gmd:deliveryPoint>
							<gmd:city>
								<gco:CharacterString>
									<xsl:value-of select="$val/rpCntInfo/cntAddress/city"/>
								</gco:CharacterString>
							</gmd:city>
							<gmd:postalCode>
								<gco:CharacterString>
									<xsl:value-of select="$val/rpCntInfo/cntAddress/postCode"/>
								</gco:CharacterString>
							</gmd:postalCode>
							<gmd:country>
								<gco:CharacterString>
									<xsl:text>FRANCE</xsl:text>
								</gco:CharacterString>
							</gmd:country>
							<gmd:electronicMailAddress>
								<gco:CharacterString>
									<xsl:value-of select="$val/rpCntInfo/cntAddress/eMailAdd"/>
								</gco:CharacterString>
							</gmd:electronicMailAddress>
						</gmd:CI_Address>
					</gmd:address>
				</gmd:CI_Contact>
			</gmd:contactInfo>
			<gmd:role>
				<gmd:CI_RoleCode>
					<xsl:attribute name="codeList">CI_RoleCode</xsl:attribute>
					<xsl:attribute name="codeListValue"><xsl:value-of select="$roleInt"/></xsl:attribute>
				</gmd:CI_RoleCode>
			</gmd:role>
		</gmd:CI_ResponsibleParty>
	</xsl:template>
	
	<!--Spatial representation used esriterm-->
	<xsl:template name="spRepInfo">
		<xsl:param name="val"/>
		<gmd:spatialRepresentationInfo>
			<xsl:choose>
				<xsl:when test="//spdoinfo/direct='Vector'">
					<gmd:MD_VectorSpatialRepresentation>
						<gmd:topologyLevel>
								<xsl:choose>
									<xsl:when test="//spatRepInfo/VectSpatRep/topLvl/TopoLevCd/@value='001'">
										<gmd:MD_TopologyLevelCode>
											<xsl:attribute name="codeList">MD_TopologyLevelCode</xsl:attribute>
											<xsl:attribute name="codeListValue">geometryOnly</xsl:attribute>
										</gmd:MD_TopologyLevelCode>
									</xsl:when>
									<xsl:when test="//spatRepInfo/VectSpatRep/topLvl/TopoLevCd/@value='002'">
										<gmd:MD_TopologyLevelCode>
											<xsl:attribute name="codeList">MD_TopologyLevelCode</xsl:attribute>
											<xsl:attribute name="codeListValue">topology1D</xsl:attribute>
										</gmd:MD_TopologyLevelCode>
									</xsl:when>
									<xsl:when test="//spatRepInfo/VectSpatRep/topLvl/TopoLevCd/@value='003'">
										<gmd:MD_TopologyLevelCode>
											<xsl:attribute name="codeList">MD_TopologyLevelCode</xsl:attribute>
											<xsl:attribute name="codeListValue">planarGraph</xsl:attribute>
										</gmd:MD_TopologyLevelCode>
									</xsl:when>
									<xsl:when test="//spatRepInfo/VectSpatRep/topLvl/TopoLevCd/@value='004'">
										<gmd:MD_TopologyLevelCode>
											<xsl:attribute name="codeList">MD_TopologyLevelCode</xsl:attribute>
											<xsl:attribute name="codeListValue">fullPlanarGraph</xsl:attribute>
										</gmd:MD_TopologyLevelCode>
									</xsl:when>
									<xsl:when test="//spatRepInfo/VectSpatRep/topLvl/TopoLevCd/@value='005'">
										<gmd:MD_TopologyLevelCode>
											<xsl:attribute name="codeList">MD_TopologyLevelCode</xsl:attribute>
											<xsl:attribute name="codeListValue">surfaceGraph</xsl:attribute>
										</gmd:MD_TopologyLevelCode>
									</xsl:when>
									<xsl:when test="//spatRepInfo/VectSpatRep/topLvl/TopoLevCd/@value='006'">
										<gmd:MD_TopologyLevelCode>
											<xsl:attribute name="codeList">MD_TopologyLevelCode</xsl:attribute>
											<xsl:attribute name="codeListValue">fullSurfaceGraph</xsl:attribute>
										</gmd:MD_TopologyLevelCode>
									</xsl:when>
									<xsl:when test="//spatRepInfo/VectSpatRep/topLvl/TopoLevCd/@value='007'">
										<gmd:MD_TopologyLevelCode>
											<xsl:attribute name="codeList">MD_TopologyLevelCode</xsl:attribute>
											<xsl:attribute name="codeListValue">topology3D</xsl:attribute>
										</gmd:MD_TopologyLevelCode>
									</xsl:when>
									<xsl:when test="//spatRepInfo/VectSpatRep/topLvl/TopoLevCd/@value='008'">
										<gmd:MD_TopologyLevelCode>
											<xsl:attribute name="codeList">MD_TopologyLevelCode</xsl:attribute>
											<xsl:attribute name="codeListValue">fullTopology3D</xsl:attribute>
										</gmd:MD_TopologyLevelCode>
									</xsl:when>
									<xsl:when test="//spatRepInfo/VectSpatRep/topLvl/TopoLevCd/@value='009'">
										<gmd:MD_TopologyLevelCode>
											<xsl:attribute name="codeList">MD_TopologyLevelCode</xsl:attribute>
											<xsl:attribute name="codeListValue">abstract</xsl:attribute>
										</gmd:MD_TopologyLevelCode>
									</xsl:when>
								</xsl:choose>
						</gmd:topologyLevel>
						<gmd:geometricObjects>
							<gmd:MD_GeometricObjects>
								<gmd:geometricObjectType>
								<xsl:choose>
								<xsl:when test="//spatRepInfo/VectSpatRep/geometObjs/geoObjTyp/GeoObjTypCd/@value='001'">
									<gmd:MD_GeometricObjectTypeCode>
			<xsl:attribute name="codeList">MD_GeometricObjectTypeCode</xsl:attribute>
			<xsl:attribute name="codeListValue">complexes</xsl:attribute>
									</gmd:MD_GeometricObjectTypeCode>
									</xsl:when>
								<xsl:when test="//spatRepInfo/VectSpatRep/geometObjs/geoObjTyp/GeoObjTypCd/@value='002'">
									<gmd:MD_GeometricObjectTypeCode>
			<xsl:attribute name="codeList">MD_GeometricObjectTypeCode</xsl:attribute>
			<xsl:attribute name="codeListValue">composite</xsl:attribute>
									</gmd:MD_GeometricObjectTypeCode>
									</xsl:when>
								<xsl:when test="//spatRepInfo/VectSpatRep/geometObjs/geoObjTyp/GeoObjTypCd/@value='003'">
									<gmd:MD_GeometricObjectTypeCode>
			<xsl:attribute name="codeList">MD_GeometricObjectTypeCode</xsl:attribute>
			<xsl:attribute name="codeListValue">curve</xsl:attribute>
									</gmd:MD_GeometricObjectTypeCode>
									</xsl:when>
								<xsl:when test="//spatRepInfo/VectSpatRep/geometObjs/geoObjTyp/GeoObjTypCd/@value='004'">
									<gmd:MD_GeometricObjectTypeCode>
			<xsl:attribute name="codeList">MD_GeometricObjectTypeCode</xsl:attribute>
			<xsl:attribute name="codeListValue">point</xsl:attribute>
									</gmd:MD_GeometricObjectTypeCode>
									</xsl:when>
								<xsl:when test="//spatRepInfo/VectSpatRep/geometObjs/geoObjTyp/GeoObjTypCd/@value='005'">
									<gmd:MD_GeometricObjectTypeCode>
			<xsl:attribute name="codeList">MD_GeometricObjectTypeCode</xsl:attribute>
			<xsl:attribute name="codeListValue">solid</xsl:attribute>
									</gmd:MD_GeometricObjectTypeCode>
									</xsl:when>
								<xsl:when test="//spatRepInfo/VectSpatRep/geometObjs/geoObjTyp/GeoObjTypCd/@value='006'">
									<gmd:MD_GeometricObjectTypeCode>
			<xsl:attribute name="codeList">MD_GeometricObjectTypeCode</xsl:attribute>
			<xsl:attribute name="codeListValue">surface</xsl:attribute>
									</gmd:MD_GeometricObjectTypeCode>
									</xsl:when>
									</xsl:choose>
								</gmd:geometricObjectType>
								<gmd:geometricObjectCount>
									<gco:Integer>
										<xsl:value-of select="efeacnt"/>
									</gco:Integer>
								</gmd:geometricObjectCount>
							</gmd:MD_GeometricObjects>
						</gmd:geometricObjects>
					</gmd:MD_VectorSpatialRepresentation>
				</xsl:when>
			</xsl:choose>
		</gmd:spatialRepresentationInfo>
	</xsl:template>
	<!-- reference system -->
	<xsl:template name="spref">
		<xsl:param name="val"/>
		<xsl:if test="$val/horizsys/cordsysn">
		<gmd:referenceSystemInfo>
			<fra:FRA_DirectReferenceSystem gco:isoType="MD_ReferenceSystem">
				<gmd:referenceSystemIdentifier>
					<gmd:RS_Identifier>
					<xsl:choose>
					<xsl:when test="$val/horizsys/cordsysn/projcsn='NTF_Lambert_II_étendu'">
						<gmd:code>
							<gmx:Anchor xlink:href="27572">NTF Lambert II Etendu</gmx:Anchor> 
						</gmd:code>
						<gmd:codeSpace>
							<gco:CharacterString>urn:ogc:def:crs:EPSG:6.11</gco:CharacterString> 
						</gmd:codeSpace> 
						<gmd:version>
							<gco:CharacterString>6.11</gco:CharacterString> 
						</gmd:version> 
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="$val/horizsys/cordsysn/projcsn">
						<gmd:code>
							<gco:CharacterString>
								<xsl:value-of select="$val/horizsys/cordsysn/projcsn"/>
							</gco:CharacterString>
						</gmd:code>
						</xsl:if>
						<xsl:if test="$val/horizsys/cordsysn/geogcsn">
						<gmd:code>
							<gco:CharacterString>
								<xsl:value-of select="$val/horizsys/cordsysn/geogcsn"/>
							</gco:CharacterString>
						</gmd:code>
						</xsl:if>	
					</xsl:otherwise>
					</xsl:choose>
					</gmd:RS_Identifier>
				</gmd:referenceSystemIdentifier>
			</fra:FRA_DirectReferenceSystem>
		</gmd:referenceSystemInfo>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="idinfo">
		<xsl:param name="val"/>
		<xsl:if test="../dataIdInfo/dataExt/vertEle/vertDatum/datumID/identCode">
		<gmd:referenceSystemInfo>
			<fra:FRA_DirectReferenceSystem gco:isoType="MD_ReferenceSystem">
				<gmd:referenceSystemIdentifier>
					<gmd:RS_Identifier>
					<xsl:choose>
					<xsl:when test="../dataIdInfo/dataExt/vertEle/vertDatum/datumID/identCode='Nivellement général de la France - IGN69'">
						<gmd:code>
							<gmx:Anchor xlink:href="5720">NGF-IGN 1969</gmx:Anchor> 
						</gmd:code>
						<gmd:codeSpace>
							<gco:CharacterString>urn:ogc:def:crs:EPSG:6.11</gco:CharacterString> 
						</gmd:codeSpace> 
						<gmd:version>
							<gco:CharacterString>6.11</gco:CharacterString> 
						</gmd:version> 
					</xsl:when>
					<xsl:otherwise>
						<gmd:code>
							<gco:CharacterString>
								<xsl:value-of select="../dataIdInfo/dataExt/vertEle/vertDatum/datumID/identCode"/>
							</gco:CharacterString>
						</gmd:code>
					</xsl:otherwise>
					</xsl:choose>
					</gmd:RS_Identifier>
				</gmd:referenceSystemIdentifier>
			</fra:FRA_DirectReferenceSystem>
		</gmd:referenceSystemInfo>
		</xsl:if>
		<gmd:identificationInfo>
			<gmd:MD_DataIdentification>
				<gmd:citation>
					<gmd:CI_Citation>
						<gmd:title>
							<gco:CharacterString>
								<xsl:value-of select="$val/citation/citeinfo/title"/>
							</gco:CharacterString>
						</gmd:title>
						<gmd:alternateTitle>
							<gco:CharacterString>
								<xsl:value-of select="../dataIdInfo/idCitation/resAltTitle"/>
							</gco:CharacterString>
						</gmd:alternateTitle>
						<xsl:for-each select="../dataIdInfo/idCitation/resRefDate">
							<gmd:date>
								<gmd:CI_Date>
									<xsl:choose>
										<xsl:when test="//Esri/ModDate">
											<gmd:date>
												<gco:Date>
													<xsl:call-template name="dateEsri">
														<xsl:with-param name="ladate" select="refDate"/>
													</xsl:call-template>
												</gco:Date>
											</gmd:date>
											<gmd:dateType>
												<xsl:choose>
													<xsl:when test="refDateType/DateTypCd/@value='001'">
														<gmd:CI_DateTypeCode codeListValue="creation" codeList="CI_DateTypeCode"/>
													</xsl:when>
													<xsl:when test="refDateType/DateTypCd/@value='002'">
														<gmd:CI_DateTypeCode codeListValue="publication" codeList="CI_DateTypeCode"/>
													</xsl:when>
													<xsl:when test="refDateType/DateTypCd/@value='003'">
														<gmd:CI_DateTypeCode codeListValue="revision" codeList="CI_DateTypeCode"/>
													</xsl:when>
													<xsl:otherwise>
														<gmd:CI_DateTypeCode codeListValue="unknown" codeList="CI_DateTypeCode"/>
													</xsl:otherwise>
												</xsl:choose>
											</gmd:dateType>
										</xsl:when>
										<xsl:otherwise>
											<gmd:date gco:nilReason="unknown"/>
										</xsl:otherwise>
									</xsl:choose>
								</gmd:CI_Date>
							</gmd:date>
						</xsl:for-each>
						<gmd:edition>
							<gco:CharacterString>
								<xsl:value-of select="../dataIdInfo/idCitation/resEd"/>
							</gco:CharacterString>
						</gmd:edition>
						<xsl:for-each select="../dataIdInfo/idCitation/citRespParty">
						<gmd:citedResponsibleParty>
							<xsl:call-template name="cntEsri">
								<xsl:with-param name="val" select="."/>
							</xsl:call-template>
						</gmd:citedResponsibleParty>
						</xsl:for-each>
					</gmd:CI_Citation>
				</gmd:citation>
				<gmd:abstract>
					<gco:CharacterString>
						<xsl:value-of select="//dataIdInfo/idAbs"/>
					</gco:CharacterString>
				</gmd:abstract>
				<gmd:status>
					<xsl:call-template name="statusEsri">
						<xsl:with-param name="val">
							<xsl:text>In work</xsl:text>
						</xsl:with-param>
					</xsl:call-template>
				</gmd:status>
				<xsl:for-each select="../dataIdInfo/idPoC">
				<gmd:pointOfContact>
					<xsl:call-template name="cntEsri">
						<xsl:with-param name="val" select="."/>
					</xsl:call-template>
				</gmd:pointOfContact>
				</xsl:for-each>
				<xsl:if test="$val/ptcontac">
					<gmd:pointOfContact>
						<xsl:call-template name="cntEsri">
							<xsl:with-param name="val" select="$val/ptcontac/cntinfo"/>
							<xsl:with-param name="roleInt">PointOfContact</xsl:with-param>
						</xsl:call-template>
					</gmd:pointOfContact>
				</xsl:if>
				<xsl:if test="//dataIdInfo/resMaint">
					<gmd:resourceMaintenance>
						<gmd:MD_MaintenanceInformation>
							<gmd:maintenanceAndUpdateFrequency>
							<xsl:choose>
							<xsl:when test="//dataIdInfo/resMaint/maintFreq/MaintFreqCd/@value='001'">
								<gmd:MD_MaintenanceFrequencyCode>
									<xsl:attribute name="codeList">MD_MaintenanceFrequencyCode</xsl:attribute>
									<xsl:attribute name="codeListValue">continual</xsl:attribute>
								</gmd:MD_MaintenanceFrequencyCode>
							</xsl:when>
							<xsl:when test="//dataIdInfo/resMaint/maintFreq/MaintFreqCd/@value='002'">
								<gmd:MD_MaintenanceFrequencyCode>
									<xsl:attribute name="codeList">MD_MaintenanceFrequencyCode</xsl:attribute>
									<xsl:attribute name="codeListValue">daily</xsl:attribute>
								</gmd:MD_MaintenanceFrequencyCode>
							</xsl:when>
							<xsl:when test="//dataIdInfo/resMaint/maintFreq/MaintFreqCd/@value='003'">
								<gmd:MD_MaintenanceFrequencyCode>
									<xsl:attribute name="codeList">MD_MaintenanceFrequencyCode</xsl:attribute>
									<xsl:attribute name="codeListValue">weekly</xsl:attribute>
								</gmd:MD_MaintenanceFrequencyCode>
							</xsl:when>
							<xsl:when test="//dataIdInfo/resMaint/maintFreq/MaintFreqCd/@value='004'">
								<gmd:MD_MaintenanceFrequencyCode>
									<xsl:attribute name="codeList">MD_MaintenanceFrequencyCode</xsl:attribute>
									<xsl:attribute name="codeListValue">fortnightly</xsl:attribute>
								</gmd:MD_MaintenanceFrequencyCode>
							</xsl:when>
							<xsl:when test="//dataIdInfo/resMaint/maintFreq/MaintFreqCd/@value='005'">
								<gmd:MD_MaintenanceFrequencyCode>
									<xsl:attribute name="codeList">MD_MaintenanceFrequencyCode</xsl:attribute>
									<xsl:attribute name="codeListValue">monthly</xsl:attribute>
								</gmd:MD_MaintenanceFrequencyCode>
							</xsl:when>
							<xsl:when test="//dataIdInfo/resMaint/maintFreq/MaintFreqCd/@value='006'">
								<gmd:MD_MaintenanceFrequencyCode>
									<xsl:attribute name="codeList">MD_MaintenanceFrequencyCode</xsl:attribute>
									<xsl:attribute name="codeListValue">quarterly</xsl:attribute>
								</gmd:MD_MaintenanceFrequencyCode>
							</xsl:when>
							<xsl:when test="//dataIdInfo/resMaint/maintFreq/MaintFreqCd/@value='007'">
								<gmd:MD_MaintenanceFrequencyCode>
									<xsl:attribute name="codeList">MD_MaintenanceFrequencyCode</xsl:attribute>
									<xsl:attribute name="codeListValue">biannually</xsl:attribute>
								</gmd:MD_MaintenanceFrequencyCode>
							</xsl:when>
							<xsl:when test="//dataIdInfo/resMaint/maintFreq/MaintFreqCd/@value='008'">
								<gmd:MD_MaintenanceFrequencyCode>
									<xsl:attribute name="codeList">MD_MaintenanceFrequencyCode</xsl:attribute>
									<xsl:attribute name="codeListValue">annually</xsl:attribute>
								</gmd:MD_MaintenanceFrequencyCode>
							</xsl:when>
							<xsl:when test="//dataIdInfo/resMaint/maintFreq/MaintFreqCd/@value='009'">
								<gmd:MD_MaintenanceFrequencyCode>
									<xsl:attribute name="codeList">MD_MaintenanceFrequencyCode</xsl:attribute>
									<xsl:attribute name="codeListValue">asNeeded</xsl:attribute>
								</gmd:MD_MaintenanceFrequencyCode>
							</xsl:when>
							<xsl:when test="//dataIdInfo/resMaint/maintFreq/MaintFreqCd/@value='010'">
								<gmd:MD_MaintenanceFrequencyCode>
									<xsl:attribute name="codeList">MD_MaintenanceFrequencyCode</xsl:attribute>
									<xsl:attribute name="codeListValue">irregular</xsl:attribute>
								</gmd:MD_MaintenanceFrequencyCode>
							</xsl:when>
							<xsl:when test="//dataIdInfo/resMaint/maintFreq/MaintFreqCd/@value='011'">
								<gmd:MD_MaintenanceFrequencyCode>
									<xsl:attribute name="codeList">MD_MaintenanceFrequencyCode</xsl:attribute>
									<xsl:attribute name="codeListValue">notPlanned</xsl:attribute>
								</gmd:MD_MaintenanceFrequencyCode>
							</xsl:when>
							<xsl:when test="//dataIdInfo/resMaint/maintFreq/MaintFreqCd/@value='012'">
								<gmd:MD_MaintenanceFrequencyCode>
									<xsl:attribute name="codeList">MD_MaintenanceFrequencyCode</xsl:attribute>
									<xsl:attribute name="codeListValue">unknown</xsl:attribute>
								</gmd:MD_MaintenanceFrequencyCode>
							</xsl:when>
							</xsl:choose>
							</gmd:maintenanceAndUpdateFrequency>
						</gmd:MD_MaintenanceInformation>
					</gmd:resourceMaintenance>
				</xsl:if>
				<xsl:if test="//dataIdInfo/descKeys">
					<xsl:for-each select="//dataIdInfo/descKeys">
						<gmd:descriptiveKeywords>
							<gmd:MD_Keywords>
								<xsl:for-each select="keyword">
									<gmd:keyword>
										<gco:CharacterString>
											<xsl:value-of select="."/>
										</gco:CharacterString>
									</gmd:keyword>
								</xsl:for-each>
									<xsl:choose>
										<xsl:when test="keyTyp/KeyTypCd/@value='001'">
											<gmd:type>
												<gmd:MD_KeywordTypeCode codeListValue="discipline" codeList="MD_KeywordTypeCode"/>
											</gmd:type>
											<xsl:if test="thesaName/resTitle">
											<gmd:thesaurusName> 
												<gmd:CI_Citation> 
													<gmd:title> 
														<gco:CharacterString><xsl:value-of select="thesaName/resTitle"></xsl:value-of></gco:CharacterString> 
													</gmd:title>
									<gmd:date>
										<gmd:CI_Date>
											<gmd:date>
												<gco:Date>
													<xsl:call-template name="dateEsri">
														<xsl:with-param name="ladate" select="thesaName/resRefDate/refDate"/>
													</xsl:call-template>
												</gco:Date>
											</gmd:date>
											<gmd:dateType>
												<xsl:choose>
													<xsl:when test="thesaName/resRefDate/refDateType/DateTypCd/@value='001'">
														<gmd:CI_DateTypeCode codeListValue="creation" codeList="CI_DateTypeCode"/>
													</xsl:when>
													<xsl:when test="refDateType/DateTypCd/@value='002'">
														<gmd:CI_DateTypeCode codeListValue="publication" codeList="CI_DateTypeCode"/>
													</xsl:when>
													<xsl:when test="refDateType/DateTypCd/@value='003'">
														<gmd:CI_DateTypeCode codeListValue="revision" codeList="CI_DateTypeCode"/>
													</xsl:when>
													<xsl:otherwise>
														<gmd:CI_DateTypeCode codeListValue="unknown" codeList="CI_DateTypeCode"/>
													</xsl:otherwise>
												</xsl:choose>
											</gmd:dateType>
										</gmd:CI_Date>
									</gmd:date>
												</gmd:CI_Citation>
											</gmd:thesaurusName>
											</xsl:if>
										</xsl:when>
										<xsl:when test="keyTyp/KeyTypCd/@value='002'">
											<gmd:type>
												<gmd:MD_KeywordTypeCode codeListValue="place" codeList="MD_KeywordTypeCode"/>
											</gmd:type>
											<xsl:if test="thesaName/resTitle">
											<gmd:thesaurusName> 
												<gmd:CI_Citation> 
													<gmd:title> 
														<gco:CharacterString><xsl:value-of select="thesaName/resTitle"></xsl:value-of></gco:CharacterString> 
													</gmd:title>
									<gmd:date>
										<gmd:CI_Date>
											<gmd:date>
												<gco:Date>
													<xsl:call-template name="dateEsri">
														<xsl:with-param name="ladate" select="thesaName/resRefDate/refDate"/>
													</xsl:call-template>
												</gco:Date>
											</gmd:date>
											<gmd:dateType>
												<xsl:choose>
													<xsl:when test="thesaName/resRefDate/refDateType/DateTypCd/@value='001'">
														<gmd:CI_DateTypeCode codeListValue="creation" codeList="CI_DateTypeCode"/>
													</xsl:when>
													<xsl:when test="refDateType/DateTypCd/@value='002'">
														<gmd:CI_DateTypeCode codeListValue="publication" codeList="CI_DateTypeCode"/>
													</xsl:when>
													<xsl:when test="refDateType/DateTypCd/@value='003'">
														<gmd:CI_DateTypeCode codeListValue="revision" codeList="CI_DateTypeCode"/>
													</xsl:when>
													<xsl:otherwise>
														<gmd:CI_DateTypeCode codeListValue="unknown" codeList="CI_DateTypeCode"/>
													</xsl:otherwise>
												</xsl:choose>
											</gmd:dateType>
										</gmd:CI_Date>
									</gmd:date>
												</gmd:CI_Citation>
											</gmd:thesaurusName>
											</xsl:if>
										</xsl:when>
										<xsl:when test="keyTyp/KeyTypCd/@value='003'">
											<gmd:type>
												<gmd:MD_KeywordTypeCode codeListValue="stratum" codeList="MD_KeywordTypeCode"/>
											</gmd:type>
											<xsl:if test="thesaName/resTitle">
											<gmd:thesaurusName> 
												<gmd:CI_Citation> 
													<gmd:title> 
														<gco:CharacterString><xsl:value-of select="thesaName/resTitle"></xsl:value-of></gco:CharacterString> 
													</gmd:title>
												</gmd:CI_Citation>
											</gmd:thesaurusName>
											</xsl:if>
										</xsl:when>
										<xsl:when test="keyTyp/KeyTypCd/@value='004'">
											<gmd:type>
												<gmd:MD_KeywordTypeCode codeListValue="temporal" codeList="MD_KeywordTypeCode"/>
											</gmd:type>
											<xsl:if test="thesaName/resTitle">
											<gmd:thesaurusName> 
												<gmd:CI_Citation> 
													<gmd:title> 
														<gco:CharacterString><xsl:value-of select="thesaName/resTitle"></xsl:value-of></gco:CharacterString> 
													</gmd:title>
												</gmd:CI_Citation>
											</gmd:thesaurusName>
											</xsl:if>
										</xsl:when>
										<xsl:when test="keyTyp/KeyTypCd/@value='005'">
											<gmd:type>
												<gmd:MD_KeywordTypeCode codeListValue="theme" codeList="MD_KeywordTypeCode"/>
											</gmd:type>
											<xsl:if test="thesaName/resTitle">
											<gmd:thesaurusName> 
												<gmd:CI_Citation> 
													<gmd:title> 
														<gco:CharacterString><xsl:value-of select="thesaName/resTitle"></xsl:value-of></gco:CharacterString> 
													</gmd:title>
							<gmd:date>
								<gmd:CI_Date>
											<gmd:date>
												<gco:Date>
													<xsl:call-template name="dateEsri">
														<xsl:with-param name="ladate" select="thesaName/resRefDate/refDate"/>
													</xsl:call-template>
												</gco:Date>
											</gmd:date>
											<gmd:dateType>
												<xsl:choose>
													<xsl:when test="thesaName/resRefDate/refDateType/DateTypCd/@value='001'">
														<gmd:CI_DateTypeCode codeListValue="creation" codeList="CI_DateTypeCode"/>
													</xsl:when>
													<xsl:when test="refDateType/DateTypCd/@value='002'">
														<gmd:CI_DateTypeCode codeListValue="publication" codeList="CI_DateTypeCode"/>
													</xsl:when>
													<xsl:when test="refDateType/DateTypCd/@value='003'">
														<gmd:CI_DateTypeCode codeListValue="revision" codeList="CI_DateTypeCode"/>
													</xsl:when>
													<xsl:otherwise>
														<gmd:CI_DateTypeCode codeListValue="unknown" codeList="CI_DateTypeCode"/>
													</xsl:otherwise>
												</xsl:choose>
											</gmd:dateType>
								</gmd:CI_Date>
							</gmd:date>
												</gmd:CI_Citation>
											</gmd:thesaurusName>
											</xsl:if>
										</xsl:when>
									</xsl:choose>
							</gmd:MD_Keywords>
						</gmd:descriptiveKeywords>
					</xsl:for-each>
				</xsl:if>
				<xsl:if test="$val/keywords/place">
					<xsl:for-each select="$val/keywords/place">
						<gmd:descriptiveKeywords>
							<gmd:MD_Keywords>
								<xsl:for-each select="placekey">
									<gmd:keyword>
										<gco:CharacterString>
											<xsl:value-of select="."/>
										</gco:CharacterString>
									</gmd:keyword>
								</xsl:for-each>
								<gmd:type>
									<gmd:MD_KeywordTypeCode codeListValue="place" codeList="MD_KeywordTypeCode"/>
								</gmd:type>
								<xsl:if test="placekt">
									<gmd:thesaurusName>
										<gmd:CI_Citation>
											<gmd:title>
												<gco:CharacterString>
													<xsl:value-of select="placekt"/>
												</gco:CharacterString>
											</gmd:title>
											<gmd:date gco:nilReason="unknown"/>
										</gmd:CI_Citation>
									</gmd:thesaurusName>
								</xsl:if>
							</gmd:MD_Keywords>
						</gmd:descriptiveKeywords>
					</xsl:for-each>
				</xsl:if>
				<xsl:if test="$val/keywords/stratum">
					<xsl:for-each select="$val/keywords/stratum">
						<gmd:descriptiveKeywords>
							<gmd:MD_Keywords>
								<xsl:for-each select="stratkey">
									<gmd:keyword>
										<gco:CharacterString>
											<xsl:value-of select="."/>
										</gco:CharacterString>
									</gmd:keyword>
								</xsl:for-each>
								<gmd:type>
									<gmd:MD_KeywordTypeCode codeListValue="stratum" codeList="MD_KeywordTypeCode"/>
								</gmd:type>
								<xsl:if test="stratkt">
									<gmd:thesaurusName>
										<gmd:CI_Citation>
											<gmd:title>
												<gco:CharacterString>
													<xsl:value-of select="stratkt"/>
												</gco:CharacterString>
											</gmd:title>
											<gmd:date gco:nilReason="unknown"/>
										</gmd:CI_Citation>
									</gmd:thesaurusName>
								</xsl:if>
							</gmd:MD_Keywords>
						</gmd:descriptiveKeywords>
					</xsl:for-each>
				</xsl:if>
				<xsl:if test="$val/keywords/temporal">
					<xsl:for-each select="$val/keywords/temporal">
						<gmd:descriptiveKeywords>
							<gmd:MD_Keywords>
								<xsl:for-each select="tempkey">
									<gmd:keyword>
										<gco:CharacterString>
											<xsl:value-of select="."/>
										</gco:CharacterString>
									</gmd:keyword>
								</xsl:for-each>
								<gmd:type>
									<gmd:MD_KeywordTypeCode codeListValue="temporal" codeList="MD_KeywordTypeCode"/>
								</gmd:type>
								<xsl:if test="tempkt">
									<gmd:thesaurusName>
										<gmd:CI_Citation>
											<gmd:title>
												<gco:CharacterString>
													<xsl:value-of select="tempkt"/>
												</gco:CharacterString>
											</gmd:title>
											<gmd:date gco:nilReason="unknown"/>
										</gmd:CI_Citation>
									</gmd:thesaurusName>
								</xsl:if>
							</gmd:MD_Keywords>
						</gmd:descriptiveKeywords>
					</xsl:for-each>
				</xsl:if>
				<!-- Constraints on Data -->
				<xsl:for-each select="../dataIdInfo/resConst">
					<!-- Constraints -->
					<gmd:resourceConstraints>
						<gmd:MD_Constraints>
							<gmd:useLimitation>
								<gco:CharacterString>
									<xsl:value-of select="Consts/useLimit"/>
								</gco:CharacterString>
							</gmd:useLimitation>
						</gmd:MD_Constraints>
					</gmd:resourceConstraints>
					<!-- Legal constraints -->
					<gmd:resourceConstraints>
						<gmd:MD_LegalConstraints>
							<xsl:for-each select="LegConsts/accessConsts">
								<xsl:choose>
									<xsl:when test="RestrictCd/@value='001'">
										<gmd:accessConstraints>
											<gmd:MD_RestrictionCode codeListValue="copyright" codeList="MD_RestrictionCode"/>
										</gmd:accessConstraints>
									</xsl:when>
									<xsl:when test="RestrictCd/@value='002'">
										<gmd:accessConstraints>
											<gmd:MD_RestrictionCode codeListValue="patent" codeList="MD_RestrictionCode"/>
										</gmd:accessConstraints>
									</xsl:when>
									<xsl:when test="RestrictCd/@value='003'">
										<gmd:accessConstraints>
											<gmd:MD_RestrictionCode codeListValue="patentPending" codeList="MD_RestrictionCode"/>
										</gmd:accessConstraints>
									</xsl:when>
									<xsl:when test="RestrictCd/@value='004'">
										<gmd:accessConstraints>
											<gmd:MD_RestrictionCode codeListValue="trademark" codeList="MD_RestrictionCode"/>
										</gmd:accessConstraints>
									</xsl:when>
									<xsl:when test="RestrictCd/@value='005'">
										<gmd:accessConstraints>
											<gmd:MD_RestrictionCode codeListValue="license" codeList="MD_RestrictionCode"/>
										</gmd:accessConstraints>
									</xsl:when>
									<xsl:when test="RestrictCd/@value='006'">
										<gmd:accessConstraints>
											<gmd:MD_RestrictionCode codeListValue="intellectualPropertyRights" codeList="MD_RestrictionCode"/>
										</gmd:accessConstraints>
									</xsl:when>
									<xsl:when test="RestrictCd/@value='007'">
										<gmd:accessConstraints>
											<gmd:MD_RestrictionCode codeListValue="restricted" codeList="MD_RestrictionCode"/>
										</gmd:accessConstraints>
									</xsl:when>
									<xsl:when test="RestrictCd/@value='008'">
										<gmd:accessConstraints>
											<gmd:MD_RestrictionCode codeListValue="otherRestrictions" codeList="MD_RestrictionCode"/>
										</gmd:accessConstraints>
									</xsl:when>
								</xsl:choose>
							</xsl:for-each>
							<xsl:for-each select="LegConsts/useConsts">
								<xsl:choose>
									<xsl:when test="RestrictCd/@value='001'">
										<gmd:useConstraints>
											<gmd:MD_RestrictionCode codeListValue="copyright" codeList="MD_RestrictionCode"/>
										</gmd:useConstraints>
									</xsl:when>
									<xsl:when test="RestrictCd/@value='002'">
										<gmd:useConstraints>
											<gmd:MD_RestrictionCode codeListValue="patent" codeList="MD_RestrictionCode"/>
										</gmd:useConstraints>
									</xsl:when>
									<xsl:when test="RestrictCd/@value='003'">
										<gmd:useConstraints>
											<gmd:MD_RestrictionCode codeListValue="patentPending" codeList="MD_RestrictionCode"/>
										</gmd:useConstraints>
									</xsl:when>
									<xsl:when test="RestrictCd/@value='004'">
										<gmd:useConstraints>
											<gmd:MD_RestrictionCode codeListValue="trademark" codeList="MD_RestrictionCode"/>
										</gmd:useConstraints>
									</xsl:when>
									<xsl:when test="RestrictCd/@value='005'">
										<gmd:useConstraints>
											<gmd:MD_RestrictionCode codeListValue="license" codeList="MD_RestrictionCode"/>
										</gmd:useConstraints>
									</xsl:when>
									<xsl:when test="RestrictCd/@value='006'">
										<gmd:useConstraints>
											<gmd:MD_RestrictionCode codeListValue="intellectualPropertyRights" codeList="MD_RestrictionCode"/>
										</gmd:useConstraints>
									</xsl:when>
									<xsl:when test="RestrictCd/@value='007'">
										<gmd:useConstraints>
											<gmd:MD_RestrictionCode codeListValue="restricted" codeList="MD_RestrictionCode"/>
										</gmd:useConstraints>
									</xsl:when>
									<xsl:when test="RestrictCd/@value='008'">
										<gmd:useConstraints>
											<gmd:MD_RestrictionCode codeListValue="otherRestrictions" codeList="MD_RestrictionCode"/>
										</gmd:useConstraints>
									</xsl:when>
								</xsl:choose>
							</xsl:for-each>
							<xsl:for-each select="LegConsts/othConsts">
								<gmd:otherConstraints>
									<gco:CharacterString>
										<xsl:value-of select="."/>
									</gco:CharacterString>
								</gmd:otherConstraints>
							</xsl:for-each>
						</gmd:MD_LegalConstraints>
					</gmd:resourceConstraints>
					<!-- security constraints -->
					<xsl:if test="SecConsts">
						<gmd:resourceConstraints>
							<gmd:MD_SecurityConstraints>
								<xsl:choose>
									<xsl:when test="SecConsts/class/ClasscationCd/@value='001'">
										<gmd:classification>
											<gmd:MD_ClassificationCode codeList="MD_ClassificationCode" codeListValue="unclassified"/>
										</gmd:classification>
									</xsl:when>
									<xsl:when test="SecConsts/class/ClasscationCd/@value='002'">
										<gmd:classification>
											<gmd:MD_ClassificationCode codeList="MD_ClassificationCode" codeListValue="restricted"/>
										</gmd:classification>
									</xsl:when>
									<xsl:when test="SecConsts/class/ClasscationCd/@value='003'">
										<gmd:classification>
											<gmd:MD_ClassificationCode codeList="MD_ClassificationCode" codeListValue="confidential"/>
										</gmd:classification>
									</xsl:when>
									<xsl:when test="SecConsts/class/ClasscationCd/@value='004'">
										<gmd:classification>
											<gmd:MD_ClassificationCode codeList="MD_ClassificationCode" codeListValue="secret"/>
										</gmd:classification>
									</xsl:when>
									<xsl:when test="SecConsts/class/ClasscationCd/@value='005'">
										<gmd:classification>
											<gmd:MD_ClassificationCode codeList="MD_ClassificationCode" codeListValue="topSecret"/>
										</gmd:classification>
									</xsl:when>
								</xsl:choose>
							</gmd:MD_SecurityConstraints>
						</gmd:resourceConstraints>
					</xsl:if>
				</xsl:for-each>
				<xsl:if test="$val/secinfo">
					<gmd:resourceConstraints>
						<gmd:MD_SecurityConstraints>
							<gmd:useLimitation>
								<gco:CharacterString/>
							</gmd:useLimitation>
							<gmd:classification>
								<xsl:call-template name="securityEsri">
									<xsl:with-param name="val">
										<xsl:value-of select="$val/secinfo/secclass"/>
									</xsl:with-param>
								</xsl:call-template>
							</gmd:classification>
							<gmd:classificationSystem>
								<gco:CharacterString>
									<xsl:value-of select="$val/secinfo/secsys"/>
								</gco:CharacterString>
							</gmd:classificationSystem>
							<gmd:handlingDescription>
								<gco:CharacterString>
									<xsl:value-of select="$val/secinfo/secsys"/>
								</gco:CharacterString>
							</gmd:handlingDescription>
						</gmd:MD_SecurityConstraints>
					</gmd:resourceConstraints>
				</xsl:if>
				<gmd:spatialRepresentationType>
					<xsl:call-template name="spRepEsri">
						<xsl:with-param name="val">
							<xsl:value-of select="//spdoinfo/direct"/>
						</xsl:with-param>
					</xsl:call-template>
				</gmd:spatialRepresentationType>
				<xsl:for-each select="../dataIdInfo/dataScale/equScale">
					<gmd:spatialResolution>
						<gmd:MD_Resolution>
							<gmd:equivalentScale>
								<gmd:MD_RepresentativeFraction>
									<gmd:denominator>
										<gco:Integer>
											<xsl:value-of select="rfDenom"/>
										</gco:Integer>
									</gmd:denominator>
								</gmd:MD_RepresentativeFraction>
							</gmd:equivalentScale>
						</gmd:MD_Resolution>
					</gmd:spatialResolution>
				</xsl:for-each>
				<xsl:for-each select="../dataIdInfo/dataScale/scaleDist">
					<gmd:spatialResolution>
						<gmd:MD_Resolution>
							<gmd:distance>
								<gco:Distance>
									<xsl:attribute name="uom"><xsl:value-of select="uom/UomScale/uomName"/></xsl:attribute>
									<xsl:value-of select="value"/>
								</gco:Distance>
							</gmd:distance>
						</gmd:MD_Resolution>
					</gmd:spatialResolution>
				</xsl:for-each>
				<gmd:language>
					<gco:CharacterString>fre</gco:CharacterString>
				</gmd:language>
				<gmd:topicCategory>
					<xsl:choose>
						<xsl:when test="../dataIdInfo/tpCat/TopicCatCd/@value='001'">
							<gmd:MD_TopicCategoryCode>farming</gmd:MD_TopicCategoryCode>
						</xsl:when>
						<xsl:when test="../dataIdInfo/tpCat/TopicCatCd/@value='002'">
							<gmd:MD_TopicCategoryCode>biota</gmd:MD_TopicCategoryCode>
						</xsl:when>
						<xsl:when test="../dataIdInfo/tpCat/TopicCatCd/@value='003'">
							<gmd:MD_TopicCategoryCode>boundaries</gmd:MD_TopicCategoryCode>
						</xsl:when>
						<xsl:when test="../dataIdInfo/tpCat/TopicCatCd/@value='004'">
							<gmd:MD_TopicCategoryCode>climatologyMeteorologyAtmosphere</gmd:MD_TopicCategoryCode>
						</xsl:when>
						<xsl:when test="../dataIdInfo/tpCat/TopicCatCd/@value='005'">
							<gmd:MD_TopicCategoryCode>economy</gmd:MD_TopicCategoryCode>
						</xsl:when>
						<xsl:when test="../dataIdInfo/tpCat/TopicCatCd/@value='006'">
							<gmd:MD_TopicCategoryCode>elevation</gmd:MD_TopicCategoryCode>
						</xsl:when>
						<xsl:when test="../dataIdInfo/tpCat/TopicCatCd/@value='007'">
							<gmd:MD_TopicCategoryCode>environment</gmd:MD_TopicCategoryCode>
						</xsl:when>
						<xsl:when test="../dataIdInfo/tpCat/TopicCatCd/@value='008'">
							<gmd:MD_TopicCategoryCode>geoscientificInformation</gmd:MD_TopicCategoryCode>
						</xsl:when>
						<xsl:when test="../dataIdInfo/tpCat/TopicCatCd/@value='009'">
							<gmd:MD_TopicCategoryCode>health</gmd:MD_TopicCategoryCode>
						</xsl:when>
						<xsl:when test="../dataIdInfo/tpCat/TopicCatCd/@value='010'">
							<gmd:MD_TopicCategoryCode>imageryBaseMapsEarthCover</gmd:MD_TopicCategoryCode>
						</xsl:when>
						<xsl:when test="../dataIdInfo/tpCat/TopicCatCd/@value='011'">
							<gmd:MD_TopicCategoryCode>intelligenceMilitary</gmd:MD_TopicCategoryCode>
						</xsl:when>
						<xsl:when test="../dataIdInfo/tpCat/TopicCatCd/@value='012'">
							<gmd:MD_TopicCategoryCode>inlandWaters</gmd:MD_TopicCategoryCode>
						</xsl:when>
						<xsl:when test="../dataIdInfo/tpCat/TopicCatCd/@value='013'">
							<gmd:MD_TopicCategoryCode>location</gmd:MD_TopicCategoryCode>
						</xsl:when>
						<xsl:when test="../dataIdInfo/tpCat/TopicCatCd/@value='014'">
							<gmd:MD_TopicCategoryCode>oceans</gmd:MD_TopicCategoryCode>
						</xsl:when>
						<xsl:when test="../dataIdInfo/tpCat/TopicCatCd/@value='015'">
							<gmd:MD_TopicCategoryCode>planningCadastre</gmd:MD_TopicCategoryCode>
						</xsl:when>
						<xsl:when test="../dataIdInfo/tpCat/TopicCatCd/@value='016'">
							<gmd:MD_TopicCategoryCode>society</gmd:MD_TopicCategoryCode>
						</xsl:when>
						<xsl:when test="../dataIdInfo/tpCat/TopicCatCd/@value='017'">
							<gmd:MD_TopicCategoryCode>structure</gmd:MD_TopicCategoryCode>
						</xsl:when>
						<xsl:when test="../dataIdInfo/tpCat/TopicCatCd/@value='018'">
							<gmd:MD_TopicCategoryCode>transportation</gmd:MD_TopicCategoryCode>
						</xsl:when>
						<xsl:when test="../dataIdInfo/tpCat/TopicCatCd/@value='019'">
							<gmd:MD_TopicCategoryCode>utilitiesCommunication</gmd:MD_TopicCategoryCode>
						</xsl:when>
						<xsl:otherwise>
							<gmd:CI_DateTypeCode codeListValue="unknown" codeList="CI_DateTypeCode"/>
						</xsl:otherwise>
					</xsl:choose>
				</gmd:topicCategory>
				<gmd:environmentDescription>
					<gco:CharacterString>
						<xsl:value-of select="$val/native"/>
					</gco:CharacterString>
				</gmd:environmentDescription>
				<gmd:extent>
					<gmd:EX_Extent>
						<gmd:geographicElement>
							<gmd:EX_GeographicBoundingBox>
								<gmd:westBoundLongitude>
									<gco:Decimal>
										<xsl:value-of select="$val/spdom/bounding/westbc"/>
									</gco:Decimal>
								</gmd:westBoundLongitude>
								<gmd:eastBoundLongitude>
									<gco:Decimal>
										<xsl:value-of select="$val/spdom/bounding/eastbc"/>
									</gco:Decimal>
								</gmd:eastBoundLongitude>
								<gmd:southBoundLatitude>
									<gco:Decimal>
										<xsl:value-of select="$val/spdom/bounding/southbc"/>
									</gco:Decimal>
								</gmd:southBoundLatitude>
								<gmd:northBoundLatitude>
									<gco:Decimal>
										<xsl:value-of select="$val/spdom/bounding/northbc"/>
									</gco:Decimal>
								</gmd:northBoundLatitude>
							</gmd:EX_GeographicBoundingBox>
						</gmd:geographicElement>
							<xsl:if test="../dataIdInfo/dataExt/tempEle/TempExtent/exTemp/TM_GeometricPrimitive/TM_Period">
						<gmd:temporalElement> 
						<gmd:EX_TemporalExtent> 
							<gmd:extent>
								<gml:TimePeriod> 
									<gml:beginPosition><xsl:call-template name="dateEsri"><xsl:with-param name="ladate" select="../dataIdInfo/dataExt/tempEle/TempExtent/exTemp/TM_GeometricPrimitive/TM_Period/begin"/></xsl:call-template><xsl:text>T00:00:00</xsl:text></gml:beginPosition>
									<gml:endPosition><xsl:call-template name="dateEsri"><xsl:with-param name="ladate" select="../dataIdInfo/dataExt/tempEle/TempExtent/exTemp/TM_GeometricPrimitive/TM_Period/end"/></xsl:call-template><xsl:text>T00:00:00</xsl:text></gml:endPosition>
								</gml:TimePeriod>
							</gmd:extent> 
						</gmd:EX_TemporalExtent> 
					</gmd:temporalElement>
						</xsl:if>
					</gmd:EX_Extent>
				</gmd:extent>
				<gmd:supplementalInformation>
					<gco:CharacterString>
						<xsl:value-of select="$val/supplinf"/>
					</gco:CharacterString>
				</gmd:supplementalInformation>
			</gmd:MD_DataIdentification>
		</gmd:identificationInfo>
	</xsl:template>
	<xsl:template name="securityEsri">
		<xsl:param name="val"/>
		<gmd:MD_ClassificationCode>
			<xsl:attribute name="codeList">MD_ClassificationCode</xsl:attribute>
			<xsl:attribute name="codeListValue"><xsl:value-of select="$fileMapping/map:Mapping/map:MD_ClassificationCode/map:code[@esri=$val]/@value"/></xsl:attribute>
		</gmd:MD_ClassificationCode>
	</xsl:template>
	
<!-- Template for spatial representation -->	
	
	<xsl:template name="spRepEsri">
		<xsl:param name="val"/>
		<gmd:MD_SpatialRepresentationTypeCode>
			<xsl:attribute name="codeList">MD_SpatialRepresentationTypeCode</xsl:attribute>
			<xsl:attribute name="codeListValue"><xsl:value-of select="$fileMapping/map:Mapping/map:MD_SpatialRepresentationTypeCode/map:code[@esri=$val]/@value"/></xsl:attribute>
		</gmd:MD_SpatialRepresentationTypeCode>
	</xsl:template>
	
	<!--Template for status -->
	
	<xsl:template name="statusEsri">
		<xsl:param name="val"/>
		<gmd:MD_ProgressCode>
			<xsl:attribute name="codeList">MD_ProgressCode</xsl:attribute>
			<xsl:attribute name="codeListValue"><xsl:value-of select="$fileMapping/map:Mapping/map:MD_ProgressCode/map:code[@esri=$val]/@value"/></xsl:attribute>
		</gmd:MD_ProgressCode>
	</xsl:template>
	
	<!--Template for distributionInfo -->
	<xsl:template name="distinfo">
		<xsl:param name="val"/>
		<gmd:distributionInfo>
			<gmd:MD_Distribution>
				<!-- format -->
				<xsl:if test="//distInfo">
					<gmd:distributionFormat>
						<gmd:MD_Format>
							<gmd:name>
								<gco:CharacterString>
									<xsl:value-of select="//distInfo/distributor/distorFormat/formatName"/>
								</gco:CharacterString>
							</gmd:name>
							<gmd:version>
								<gco:CharacterString>
									<xsl:value-of select="//distInfo/distributor/distorFormat/formatVer"/>
								</gco:CharacterString>
							</gmd:version>
						</gmd:MD_Format>
					</gmd:distributionFormat>
				</xsl:if>
				<!--distributor and fees -->
				<gmd:distributor>
					<gmd:MD_Distributor>
						<xsl:choose>
							<xsl:when test="//distInfo/distributor/distorCont">
								<gmd:distributorContact>
									<xsl:call-template name="distEsri">
										<xsl:with-param name="val" select="//distInfo/distributor/distorCont"/>
										<xsl:with-param name="roleInt">distributor</xsl:with-param>
									</xsl:call-template>
								</gmd:distributorContact>
							</xsl:when>
							<xsl:otherwise>
								<gmd:distributorContact gco:nilReason="Unknown"/>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:if test="$val/stdorder">
							<xsl:for-each select="$val/stdorder">
								<gmd:distributionOrderProcess>
									<gmd:MD_StandardOrderProcess>
										<gmd:fees>
											<gco:CharacterString>
												<xsl:value-of select="//distInfo/distributor/distorOrdPrc/resFees"/>
											</gco:CharacterString>
										</gmd:fees>
										<gmd:orderingInstructions>
											<gco:CharacterString>
												<xsl:value-of select="//distInfo/distributor/distorOrdPrc/ordInstr"/>
										</gco:CharacterString>
										</gmd:orderingInstructions>
										<gmd:turnaround>
											<gco:CharacterString><xsl:value-of select="//distInfo/distributor/distorOrdPrc/ordTurn"/></gco:CharacterString>
										</gmd:turnaround>
									</gmd:MD_StandardOrderProcess>
								</gmd:distributionOrderProcess>
							</xsl:for-each>
						</xsl:if>
					</gmd:MD_Distributor>
				</gmd:distributor>
				<!-- online access -->
				<xsl:if test="//distInfo/distributor/distorTran/onLineSrc">
					<xsl:for-each select="//distInfo/distributor/distorTran/onLineSrc">
						<xsl:call-template name="distinfo2">
							<xsl:with-param name="val" select="."/>
						</xsl:call-template>
					</xsl:for-each>
				</xsl:if>
				<!-- offline access -->
			</gmd:MD_Distribution>
		</gmd:distributionInfo>
	</xsl:template>
	<xsl:template name="distinfo2">
		<xsl:param name="val"/>
		<gmd:transferOptions>
			<gmd:MD_DigitalTransferOptions>
				<gmd:onLine>
					<gmd:CI_OnlineResource>
						<gmd:linkage>
							<gmd:URL>
								<xsl:value-of select="$val/linkage"/>
							</gmd:URL>
						</gmd:linkage>
						<gmd:protocol>
							<gco:CharacterString>file</gco:CharacterString>
						</gmd:protocol>
						<gmd:name>
							<gco:CharacterString>
								<xsl:value-of select="//idinfo/citation/citeinfo/ftname"/>
							</gco:CharacterString>
						</gmd:name>
						<gmd:description>
						<xsl:choose>
						<xsl:when test="//distInfo/distributor/distorTran/onLineSrc/orDesc='001'">
						<gco:CharacterString>Données et cartes dynamiques</gco:CharacterString>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/onLineSrc/orDesc='002'">
						<gco:CharacterString>Données téléchargeables</gco:CharacterString>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/onLineSrc/orDesc='003'">
						<gco:CharacterString>Données hors connexion</gco:CharacterString>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/onLineSrc/orDesc='004'">
						<gco:CharacterString>Cartes statiques de type image</gco:CharacterString>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/onLineSrc/orDesc='005'">
						<gco:CharacterString>Autres documents</gco:CharacterString>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/onLineSrc/orDesc='006'">
						<gco:CharacterString>Applications</gco:CharacterString>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/onLineSrc/orDesc='007'">
						<gco:CharacterString>Services géographiques</gco:CharacterString>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/onLineSrc/orDesc='008'">
						<gco:CharacterString>Centres d'information</gco:CharacterString>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/onLineSrc/orDesc='009'">
						<gco:CharacterString>Fichiers cartographiques</gco:CharacterString>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/onLineSrc/orDesc='010'">
						<gco:CharacterString>Activités géographiques</gco:CharacterString>
						</xsl:when>
						</xsl:choose>
						</gmd:description>
						<xsl:choose>
							<xsl:when test="//distInfo/distributor/distorTran/onLineSrc/orFunct/OnFunctCd/@value='001'">
						<gmd:function>
							<gmd:CI_OnLineFunctionCode codeListValue="download" codeList="CI_OnLineFunctionCode"/>
						</gmd:function>
							</xsl:when>
							<xsl:when test="//distInfo/distributor/distorTran/onLineSrc/orFunct/OnFunctCd/@value='002'">
						<gmd:function>
							<gmd:CI_OnLineFunctionCode codeListValue="information" codeList="CI_OnLineFunctionCode"/>
						</gmd:function>
							</xsl:when>
							<xsl:when test="//distInfo/distributor/distorTran/onLineSrc/orFunct/OnFunctCd/@value='003'">
						<gmd:function>
							<gmd:CI_OnLineFunctionCode codeListValue="offlineAccess" codeList="CI_OnLineFunctionCode"/>
						</gmd:function>
							</xsl:when>
							<xsl:when test="//distInfo/distributor/distorTran/onLineSrc/orFunct/OnFunctCd/@value='004'">
						<gmd:function>
							<gmd:CI_OnLineFunctionCode codeListValue="order" codeList="CI_OnLineFunctionCode"/>
						</gmd:function>
							</xsl:when>
							<xsl:when test="//distInfo/distributor/distorTran/onLineSrc/orFunct/OnFunctCd/@value='005'">
						<gmd:function>
							<gmd:CI_OnLineFunctionCode codeListValue="search" codeList="CI_OnLineFunctionCode"/>
						</gmd:function>
							</xsl:when>
							<xsl:otherwise>
							</xsl:otherwise>
						</xsl:choose>
					</gmd:CI_OnlineResource>
				</gmd:onLine>
				<gmd:offLine> 
					<gmd:MD_Medium>
						<gmd:name>
						<xsl:choose>
						<xsl:when test="//distInfo/distributor/distorTran/offLineMed/medName/MedNameCd/@value='001'">
							<gmd:MD_MediumNameCode codeList="MD_MediumNameCode" codeListValue="cdRom"/>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/offLineMed/medName/MedNameCd/@value='002'">
							<gmd:MD_MediumNameCode codeList="MD_MediumNameCode" codeListValue="dvd"/>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/offLineMed/medName/MedNameCd/@value='003'">
							<gmd:MD_MediumNameCode codeList="MD_MediumNameCode" codeListValue="dvdRom"/>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/offLineMed/medName/MedNameCd/@value='004'">
							<gmd:MD_MediumNameCode codeList="MD_MediumNameCode" codeListValue="3halflnchFloppy"/>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/offLineMed/medName/MedNameCd/@value='005'">
							<gmd:MD_MediumNameCode codeList="MD_MediumNameCode" codeListValue="5quarterInchFloppy"/>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/offLineMed/medName/MedNameCd/@value='006'">
							<gmd:MD_MediumNameCode codeList="MD_MediumNameCode" codeListValue="7trackTape"/>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/offLineMed/medName/MedNameCd/@value='007'">
							<gmd:MD_MediumNameCode codeList="MD_MediumNameCode" codeListValue="9trackTape"/>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/offLineMed/medName/MedNameCd/@value='008'">
							<gmd:MD_MediumNameCode codeList="MD_MediumNameCode" codeListValue="3480Cartridge"/>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/offLineMed/medName/MedNameCd/@value='009'">
							<gmd:MD_MediumNameCode codeList="MD_MediumNameCode" codeListValue="3490Cartridge"/>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/offLineMed/medName/MedNameCd/@value='010'">
							<gmd:MD_MediumNameCode codeList="MD_MediumNameCode" codeListValue="3580Cartridge"/>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/offLineMed/medName/MedNameCd/@value='011'">
							<gmd:MD_MediumNameCode codeList="MD_MediumNameCode" codeListValue="4mmCartridgeTape"/>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/offLineMed/medName/MedNameCd/@value='012'">
							<gmd:MD_MediumNameCode codeList="MD_MediumNameCode" codeListValue="8mmCartridgeTape"/>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/offLineMed/medName/MedNameCd/@value='013'">
							<gmd:MD_MediumNameCode codeList="MD_MediumNameCode" codeListValue="1quarterInchCartridgeTape"/>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/offLineMed/medName/MedNameCd/@value='014'">
							<gmd:MD_MediumNameCode codeList="MD_MediumNameCode" codeListValue="digitalLinearTape"/>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/offLineMed/medName/MedNameCd/@value='015'">
							<gmd:MD_MediumNameCode codeList="MD_MediumNameCode" codeListValue="onLine"/>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/offLineMed/medName/MedNameCd/@value='016'">
							<gmd:MD_MediumNameCode codeList="MD_MediumNameCode" codeListValue="satellite"/>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/offLineMed/medName/MedNameCd/@value='017'">
							<gmd:MD_MediumNameCode codeList="MD_MediumNameCode" codeListValue="telephoneLink"/>
						</xsl:when>
						<xsl:when test="//distInfo/distributor/distorTran/offLineMed/medName/MedNameCd/@value='018'">
							<gmd:MD_MediumNameCode codeList="MD_MediumNameCode" codeListValue="hardcopy"/>
						</xsl:when>
						</xsl:choose>
						</gmd:name> 
					</gmd:MD_Medium> 
				</gmd:offLine> 
			</gmd:MD_DigitalTransferOptions>
		</gmd:transferOptions>
	</xsl:template>
	<xsl:template name="dataqual">
		<xsl:param name="val"/>
		<gmd:dataQualityInfo>
			<gmd:DQ_DataQuality>
				<gmd:scope>
					<gmd:DQ_Scope>
						<gmd:level>
							<xsl:call-template name="hierEsri">
								<xsl:with-param name="val">
									<xsl:value-of select="$val/../mdHrLv/ScopeCd/@value"/>
								</xsl:with-param>
							</xsl:call-template>
						</gmd:level>
					</gmd:DQ_Scope>
				</gmd:scope>

				<!-- lineage-->
				<gmd:lineage>
					<gmd:LI_Lineage>
						<gmd:statement>
							<gco:CharacterString>
								<xsl:value-of select="$val/dataLineage/statement"/>
							</gco:CharacterString>
						</gmd:statement>

						<!-- source -->
						<xsl:if test="$val/lineage/srcinfo">
							<xsl:for-each select="$val/lineage/srcinfo">
								<gmd:source>
									<gmd:LI_Source>
										<gmd:description>
											<gco:CharacterString>
												<xsl:value-of select="srccontr"/>
											</gco:CharacterString>
										</gmd:description>
										<gmd:scaleDenominator>
											<gmd:MD_RepresentativeFraction>
												<gmd:denominator>
													<gco:Integer>
														<xsl:value-of select="srcscale"/>
													</gco:Integer>
												</gmd:denominator>
											</gmd:MD_RepresentativeFraction>
										</gmd:scaleDenominator>
										<xsl:if test="srccite">
											<gmd:sourceCitation>
												<gmd:CI_Citation>
													<gmd:title>
														<gco:CharacterString>
															<xsl:value-of select="srccite/citeinfo/title"/>
														</gco:CharacterString>
													</gmd:title>
													<gmd:date>
														<gmd:CI_Date>
															<xsl:choose>
																<xsl:when test="srccite/citeinfo/pubdate">
																	<gmd:date>
																		<gco:Date>
																			<xsl:call-template name="dateEsri">
																				<xsl:with-param name="ladate" select="srccite/citeinfo/pubdate"/>
																			</xsl:call-template>
																		</gco:Date>
																	</gmd:date>
																	<gmd:dateType>
																		<gmd:CI_DateTypeCode codeListValue="publication" codeList="CI_DateTypeCode"/>
																	</gmd:dateType>
																</xsl:when>
																<xsl:otherwise>
																	<gmd:date gco:nilReason="unknown"/>
																</xsl:otherwise>
															</xsl:choose>
														</gmd:CI_Date>
													</gmd:date>
												</gmd:CI_Citation>
											</gmd:sourceCitation>
										</xsl:if>
									</gmd:LI_Source>
								</gmd:source>
							</xsl:for-each>
						</xsl:if>
					</gmd:LI_Lineage>
				</gmd:lineage>
			</gmd:DQ_DataQuality>
		</gmd:dataQualityInfo>
	</xsl:template>
	<!--Template for date -->
	<xsl:template name="dateEsri">
		<xsl:param name="ladate"/>
		<xsl:param name="mois">
			<xsl:choose>
				<xsl:when test="substring($ladate,5,2)=''">01</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="substring($ladate,5,2)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:param>
		<xsl:param name="jour">
			<xsl:choose>
				<xsl:when test="substring($ladate,7,2)=''">01</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="substring($ladate,7,2)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:param>
		<xsl:value-of select="substring($ladate,1,4)"/>-<xsl:value-of select="$mois"/>-<xsl:value-of select="$jour"/>
	</xsl:template>
</xsl:stylesheet>
